summaryrefslogtreecommitdiffstats
path: root/kipi-plugins/jpeglossless/imagerotate.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:26:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:26:11 -0600
commit21b5bfab4d2467a0f644d653e12f169ea4afcaaf (patch)
treee49908eff7827ba1b2272b9886effc0defaae487 /kipi-plugins/jpeglossless/imagerotate.cpp
parent9b89f2dc5b2290da9d3aa0426d5b27ab56cdcb75 (diff)
downloadkipi-plugins-21b5bfab4d2467a0f644d653e12f169ea4afcaaf.tar.gz
kipi-plugins-21b5bfab4d2467a0f644d653e12f169ea4afcaaf.zip
Rename additional global TQt functions
Diffstat (limited to 'kipi-plugins/jpeglossless/imagerotate.cpp')
-rw-r--r--kipi-plugins/jpeglossless/imagerotate.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kipi-plugins/jpeglossless/imagerotate.cpp b/kipi-plugins/jpeglossless/imagerotate.cpp
index 6b030f6..56dd8a8 100644
--- a/kipi-plugins/jpeglossless/imagerotate.cpp
+++ b/kipi-plugins/jpeglossless/imagerotate.cpp
@@ -11,7 +11,7 @@
* Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
*
* NOTE: Do not use kdDebug() in this implementation because
* it will be multithreaded. Use qDebug() instead.
* See B.K.O #133026 for details.
*
* This program is free software; you can redistribute it
@@ -159,7 +159,7 @@ bool ImageRotate::rotateJPEG(const TQString& src, const TQString& dest, RotateAc
}
default:
{
- qDebug("ImageRotate: Nonstandard rotation angle");
+ tqDebug("ImageRotate: Nonstandard rotation angle");
err = i18n("Nonstandard rotation angle");
return false;
}
@@ -200,7 +200,7 @@ bool ImageRotate::rotateImageMagick(const TQString& src, const TQString& dest,
}
default:
{
- qDebug("ImageRotate: Nonstandard rotation angle");
+ tqDebug("ImageRotate: Nonstandard rotation angle");
err = i18n("Nonstandard rotation angle");
return false;
}
@@ -208,10 +208,10 @@ bool ImageRotate::rotateImageMagick(const TQString& src, const TQString& dest,
process << src + TQString("[0]") << dest;
- qDebug("ImageMagick Command line args:");
+ tqDebug("ImageMagick Command line args:");
TQValueList<TQCString> args = process.args();
for (TQValueList<TQCString>::iterator it = args.begin(); it != args.end(); ++it)
- qDebug("%s", (const char*)(*it));
+ tqDebug("%s", (const char*)(*it));
connect(&process, TQT_SIGNAL(receivedStderr(KProcess *, char*, int)),
this, TQT_SLOT(slotReadStderr(KProcess*, char*, int)));
@@ -11,7 +11,7 @@
*
* NOTE: Do not use kdDebug() in this implementation because
- * it will be multithreaded. Use qDebug() instead.
+ * it will be multithreaded. Use tqDebug() instead.
* See B.K.O #133026 for details.
*